@@ -13,7 +13,7 @@ from urllib.request import urlopen
 from zipfile import BadZipFile, ZipFile
 
 from ibkr_report.definitions import (
-    _DATE,
+    DATE_FORMAT,
     EXCHANGE_RATES_URL,
     MAX_BACKTRACK_DAYS,
     MAX_HTTP_RETRIES,
@@ -41,7 +41,7 @@ class ExchangeRates:
         """
         url = url or EXCHANGE_RATES_URL
         storage = get_storage(storage_type=storage_type)
-        # TODO: mypy 0.910 https://github.com/python/mypy/pull/9629
+        # TODO: mypy 0.910 https://github.com/python/mypy/pull/9629  # pylint: disable=fixme
         self.storage = storage(**kwargs)  # type: ignore
         self.rates = self.storage.load()
         if not self.rates:
@@ -71,7 +71,7 @@ class ExchangeRates:
                     rates[items[0]] = date_rates
         log.debug("Adding currency data from %d rows.", len(rates))
         self.rates = {**self.rates, **rates}
-        # TODO: Python3.9+ "self.rates |= rates"
+        # TODO: Python3.9+ "self.rates |= rates"  # pylint: disable=fixme
 
     def download_official_rates(self, url: str) -> None:
         """Downloads the official currency exchange rates from European Central Bank
@@ -115,7 +115,7 @@ class ExchangeRates:
 
         original_date = search_date = get_date(date_str)
         while original_date - search_date <= timedelta(MAX_BACKTRACK_DAYS):
-            date_rates = self.rates.get(search_date.strftime(_DATE), {})
+            date_rates = self.rates.get(search_date.strftime(DATE_FORMAT), {})
             from_rate = "1" if currency_from == "EUR" else date_rates.get(currency_from)
             to_rate = "1" if currency_to == "EUR" else date_rates.get(currency_to)
             if from_rate is not None and to_rate is not None:
