@@ -1,17 +1,19 @@
 """Tools and utility functions."""
 
+from __future__ import annotations
+
+import hashlib
 import logging
 import os
 import re
 from base64 import b64encode
 from datetime import date, datetime
 from decimal import Decimal
-from hashlib import sha384
 from typing import Any, Dict
 
 from flask import current_app
 
-from ibkr_report.definitions import _DATE_STR_FORMATS, LOGGING_LEVEL
+from ibkr_report.definitions import _DEFAULT_LOGGING, DATE_STR_FORMATS, LOGGING_LEVEL
 
 _cache: Dict = {}
 _MAXCACHE = 10
@@ -45,7 +47,7 @@ class Cache:
 
 def get_date(date_str: str) -> date:
     """Converts a string formatted date to a date object."""
-    for date_format in _DATE_STR_FORMATS:
+    for date_format in DATE_STR_FORMATS:
         try:
             return datetime.strptime(date_str, date_format).date()
         except ValueError:
@@ -86,30 +88,33 @@ def is_number(number_str: str) -> bool:
 
 def calculate_sri_on_file(filename: str) -> str:
     """Calculate Subresource Integrity string."""
-    hash_digest = hash_sum(filename, sha384()).digest()
-    hash_base64 = b64encode(hash_digest).decode()
+    hash_func = hashlib.sha384()
+    update_hash(filename, hash_func)
+    hash_base64 = b64encode(hash_func.digest()).decode()
     return f"sha384-{hash_base64}"
 
 
-# TODO: mypy 0.910 "BinaryIO" has no attribute "readinto"
-def hash_sum(filename, hash_func):
+# TODO: mypy 0.910 "BinaryIO" has no attribute "readinto"  # pylint: disable=fixme
+# TODO: pylint "Module 'hashlib' has no '_Hash' member"  # pylint: disable=fixme
+#       https://github.com/PyCQA/pylint/issues/5395
+def update_hash(
+    filename: str, hash_func: hashlib._Hash  # pylint: disable=no-member
+) -> None:
     """Compute message digest from a file."""
     byte_array = bytearray(128 * 1024)
     memory_view = memoryview(byte_array)
     with open(filename, "rb", buffering=0) as file:
-        for block in iter(lambda: file.readinto(memory_view), 0):
+        for block in iter(lambda: file.readinto(memory_view), 0):  # type: ignore
             hash_func.update(memory_view[:block])
-    return hash_func
 
 
 def set_logging() -> None:
     """Set logging level according to the ENV variable LOGGING_LEVEL."""
-    if not current_app.debug:
-        level = logging.getLevelName(LOGGING_LEVEL.upper())
-        if isinstance(level, int):
-            current_app.logger.setLevel(level)
-        else:
-            current_app.logger.setLevel(logging.WARNING)
+    level = logging.getLevelName(LOGGING_LEVEL.upper())
+    if isinstance(level, int):
+        current_app.logger.setLevel(level)
+    else:
+        current_app.logger.setLevel(logging.getLevelName(_DEFAULT_LOGGING))
     log_level = logging.getLevelName(current_app.logger.level)
     current_app.logger.debug(f"Logging level: {log_level}")
 
